MethodChannelAppInstallerPlus class
An implementation of AppInstallerPlusPlatform that uses method channels.
This class handles the communication between the Dart code and the native Android platform to trigger the APK installation process after a successful download.
- Inheritance
-
- Object
- PlatformInterface
- AppInstallerPlusPlatform
- MethodChannelAppInstallerPlus
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
downloadAndInstallApk(
{required String downloadFileUrl, void onProgress(double progress)?, void onError(String error)?, void onTimeLeft(String error)?, void onSpeed(String error)?, void onTotalSize(String error)?, void onDownloadedSize(String error)?, String? downloadFileName, bool deleteOnError = false}) → Future< void> -
Downloads an APK file and invokes the native method channel to install it.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited