ApiService class

Constructors

ApiService()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelDownload() → void
downloadFile({required String downloadFileUrl, void onProgress(double progress)?, void onError(String error)?, void onTimeLeft(String error)?, void onSpeed(String error)?, void onTotalSize(String error)?, void onDownloadedSize(String error)?, String? downloadFileName}) Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited